<?php
/**
 * Customizer settings for this theme.
 *
 * @package WordPress
 * @subpackage ID-SK
 * @since ID-SK 1.0
 */

if ( ! class_exists( 'Idsktmp_Customize' ) ) {

    /**
	 * CUSTOMIZER SETTINGS
	 */
    class Idsktmp_Customize {
		/**
		 * Register customizer options.
		 *
		 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
		 */
		public static function idsktmp_register( $wp_customize ) {

            /**
             * Header Extended section
             */
            $wp_customize->add_section(
                'idsktmp_header_extended',
                array(
                    'title'      => __( 'Hlavička pre webové sídla', 'idsk-template' ),
                    'priority'   => 30,
                )
            );

                /* Header Extended - logos */
                $wp_customize->add_setting(
                    'idsktmp_main_logo',
                    array(
                        'sanitize_callback' => array( __CLASS__, 'idsktmp_sanitize_images' )
                    )
                );
                $wp_customize->add_control(new WP_Customize_Image_Control($wp_customize, 'idsktmp_main_logo', array(
                    'label' => __( 'Nahraj hlavné logo', 'idsk-template' ),
                    'section' => 'idsktmp_header_extended',
                    'settings' => 'idsktmp_main_logo',
                    'description' => __( 'Hlavne logo - farebne', 'idsk-template' )
                )));

                $wp_customize->add_setting(
                    'idsktmp_main_logo_white',
                    array(
                        'sanitize_callback' => array( __CLASS__, 'idsktmp_sanitize_images' )
                    )
                );
                $wp_customize->add_control(new WP_Customize_Image_Control($wp_customize, 'idsktmp_main_logo_white', array(
                    'label' => __( 'Nahraj hlavné logo - biele', 'idsk-template' ),
                    'section' => 'idsktmp_header_extended',
                    'settings' => 'idsktmp_main_logo_white',
                    'description' => __( 'Hlavne logo - biele - pri zobrazeni menu na mobile', 'idsk-template' )
                )));

                $wp_customize->add_setting(
                    'idsktmp_main_logo_small',
                    array(
                        'sanitize_callback' => array( __CLASS__, 'idsktmp_sanitize_images' )
                    )
                );
                $wp_customize->add_control(new WP_Customize_Image_Control($wp_customize, 'idsktmp_main_logo_small', array(
                    'label' => __( 'Nahraj hlavné logo - mobil', 'idsk-template' ),
                    'section' => 'idsktmp_header_extended',
                    'settings' => 'idsktmp_main_logo_small',
                    'description' => __( 'Hlavne logo - farebne - pri scrollovani na mobile sa hlavicka zmensi', 'idsk-template' )
                )));

                $wp_customize->add_setting(
                    'main_logo_small_white',
                    array(
                        'sanitize_callback' => array( __CLASS__, 'idsktmp_sanitize_images' )
                    )
                );
                $wp_customize->add_control(new WP_Customize_Image_Control($wp_customize, 'main_logo_small_white', array(
                    'label' => __( 'Nahraj hlavné logo - mobil biele', 'idsk-template' ),
                    'section' => 'idsktmp_header_extended',
                    'settings' => 'main_logo_small_white',
                    'description' => __( 'Hlavne logo - biele - pri scrollovani na mobile ak sa hlavicka zmensi a zapne menu', 'idsk-template' )
                )));

                /* Header Extended - Search */
                $wp_customize->add_setting(
                    'enable_header_search',
                    array(
                        'capability'        => 'edit_theme_options',
                        'default'           => true,
                        'sanitize_callback' => array( __CLASS__, 'idsktmp_sanitize_checkbox' ),
                    )
                );
                $wp_customize->add_control(
                    'enable_header_search',
                    array(
                        'type'     => 'checkbox',
                        'section'  => 'idsktmp_header_extended',
                        'priority' => 10,
                        'label'    => __( 'Zobraziť vyhľadávanie v hlavičke', 'idsk-template' ),
                    )
                );

                /* Header Extended - Social Media */
                $wp_customize->add_setting(
                    'idsktmp_social_icon_instagram',
                    array(
                        'sanitize_callback' => 'esc_url_raw'
                    )
                );
                $wp_customize->add_control(
                    'idsktmp_social_icon_instagram_control',
                    array(
                        'label'      => __( 'Instagram url', 'idsk-template' ),
                        'section'    => 'idsktmp_header_extended',
                        'settings'   => 'idsktmp_social_icon_instagram',
                        'type'       => 'url'
                    )
                );
                $wp_customize->add_setting(
                    'idsktmp_social_icon_linkedin',
                    array(
                        'sanitize_callback' => 'esc_url_raw'
                    )
                );
                $wp_customize->add_control(
                    'idsktmp_social_icon_linkedin_control',
                    array(
                        'label'      => __( 'LinkedIn url', 'idsk-template' ),
                        'section'    => 'idsktmp_header_extended',
                        'settings'   => 'idsktmp_social_icon_linkedin',
                        'type'       => 'url'
                    )
                );
                $wp_customize->add_setting(
                    'idsktmp_social_icon_facebook',
                    array(
                        'sanitize_callback' => 'esc_url_raw'
                    )
                );
                $wp_customize->add_control(
                    'idsktmp_social_icon_facebook_control',
                    array(
                        'label'      => __( 'Facebook url', 'idsk-template' ),
                        'section'    => 'idsktmp_header_extended',
                        'settings'   => 'idsktmp_social_icon_facebook',
                        'type'       => 'url'
                    )
                );
                $wp_customize->add_setting(
                    'idsktmp_social_icon_twitter',
                    array(
                        'sanitize_callback' => 'esc_url_raw'
                    )
                );
                $wp_customize->add_control(
                    'idsktmp_social_icon_twitter_control',
                    array(
                        'label'      => __( 'Twiter url', 'idsk-template' ),
                        'section'    => 'idsktmp_header_extended',
                        'settings'   => 'idsktmp_social_icon_twitter',
                        'type'       => 'url'
                    )
                );

            /**
             * Footer extended section
             */
            $wp_customize->add_section(
                'idsktmp_footer_extened',
                array(
                    'title'      => __( 'Pätička pre webové sídla', 'idsk-template' ),
                    'priority'   => 31,
                )
            );

                /* Footer extended - logo */
                $wp_customize->add_setting(
                    'idsktmp_footer_extended_logo',
                    array(
                        'sanitize_callback' => array( __CLASS__, 'idsktmp_sanitize_images' )
                    )
                );
                $wp_customize->add_control(new WP_Customize_Image_Control($wp_customize, 'idsktmp_footer_extended_logo', array(
                    'label' => __( 'Nahraj hlavné logo - mobil biele', 'idsk-template' ),
                    'section' => 'idsktmp_footer_extened',
                    'settings' => 'idsktmp_footer_extended_logo',
                    'description' => __( 'Hlavne logo - biele - pri scrollovani na mobile ak sa hlavicka zmensi a zapne menu', 'idsk-template' )
                )));

                /* Footer extended - up-button */
                $wp_customize->add_setting(
                    'idsktmp_footer_exteded_up_button',
                    array(
                        'capability'        => 'edit_theme_options',
                        'default'           => true,
                        'sanitize_callback' => array( __CLASS__, 'idsktmp_sanitize_checkbox' ),
                    )
                );
                $wp_customize->add_control(
                    'idsktmp_footer_exteded_up_button',
                    array(
                        'type'     => 'checkbox',
                        'section'  => 'idsktmp_footer_extened',
                        'priority' => 10,
                        'label'    => __( 'Zobraziť up-button v pätičke', 'idsk-template' )
                    )
                );

                /* Footer extended - Feedback form */
                $wp_customize->add_setting(
                    'idsktmp_footer_exteded_feedback_form',
                    array(
                        'capability'        => 'edit_theme_options',
                        'default'           => true,
                        'sanitize_callback' => array( __CLASS__, 'idsktmp_sanitize_checkbox' )
                    )
                );
                $wp_customize->add_control(
                    'idsktmp_footer_exteded_feedback_form',
                    array(
                        'type'     => 'checkbox',
                        'section'  => 'idsktmp_footer_extened',
                        'priority' => 10,
                        'label'    => __( 'Zobraziť feedback form v pätičke', 'idsk-template' )
                    )
                );
                // if idsktmp_footer_exteded_feedback_form is checked, show these settings
                // set feedback title
                $wp_customize->add_setting(
                    'idsktmp_footer_exteded_feedback_title',
                    array(
                        'sanitize_callback' => array( __CLASS__, 'idsktmp_sanitize_text' )
                    )
                );
                $wp_customize->add_control(
                    'idsktmp_footer_exteded_feedback_title_control',
                    array(
                        'label'      => __( 'Prieskum spokojností - title', 'idsk-template' ),
                        'section'    => 'idsktmp_footer_extened',
                        'settings'   => 'idsktmp_footer_exteded_feedback_title',
                        'type'       => 'text',
                        'active_callback' => array( __CLASS__, 'idsktmp_is_footer_extended_feedback_form' )
                    )
                );
                // set feedback content
                $wp_customize->add_setting(
                    'idsktmp_footer_exteded_feedback_content',
                    array(
                        'sanitize_callback' => array( __CLASS__, 'idsktmp_sanitize_text' )
                    )
                );
                $wp_customize->add_control(
                    'idsktmp_footer_exteded_feedback_content_control',
                    array(
                        'label'      => __( 'Prieskum spokojností - Kontent', 'idsk-template' ),
                        'section'    => 'idsktmp_footer_extened',
                        'settings'   => 'idsktmp_footer_exteded_feedback_content',
                        'type'       => 'textarea',
                        'active_callback' => array( __CLASS__, 'idsktmp_is_footer_extended_feedback_form' )
                    )
                );
                // set feedback endpoint link
                $wp_customize->add_setting(
                    'idsktmp_footer_exteded_feedback_link',
                    array(
                        'sanitize_callback' => 'esc_url_raw' //cleans URL from all invalid characters
                    )
                );
                $wp_customize->add_control(
                    'idsktmp_footer_exteded_feedback_link_control',
                    array(
                        'label'      => __( 'Prieskum spokojností - URL', 'idsk-template' ),
                        'section'    => 'idsktmp_footer_extened',
                        'settings'   => 'idsktmp_footer_exteded_feedback_link',
                        'type'       => 'url',
                        'active_callback' => array( __CLASS__, 'idsktmp_is_footer_extended_feedback_form' )
                    )
                );
            
            /**
             * Theme basic settings
             */
            $wp_customize->add_section(
                'idsktmp_main_settings',
                array(
                    'title'      => __( 'Hlavné nastavenia témy', 'idsk-template' ),
                    'priority'   => 10,
                )
            );

                // global info
                $wp_customize->add_setting(
                    'idsktmp_main_settings_global_info',
                    array(
                        'sanitize_callback' => array( __CLASS__, 'idsktmp_sanitize_text' ),
                    )
                );
                $wp_customize->add_control(
                    'idsktmp_main_settings_global_info_control',
                    array(
                        'label'      => __( 'Globálna informácia na stránke', 'idsk-template' ),
                        'section'    => 'idsktmp_main_settings',
                        'settings'   => 'idsktmp_main_settings_global_info',
                        'type'       => 'textarea',
                    )
                );
                $wp_customize->add_setting(
                    'idsktmp_main_settings_global_info_type',
                    array(
                        'default'    => 'info',
                        'sanitize_callback' => array( __CLASS__, 'idsktmp_sanitize_radio')
                    )
                );
                $wp_customize->add_control(
                    'idsktmp_main_settings_global_info_type',
                    array(
                        'label'      => __( 'Typ informačnej lišty na stránke', 'idsk-template' ),
                        'section'    => 'idsktmp_main_settings',
                        'settings'   => 'idsktmp_main_settings_global_info_type',
                        'type'       => 'radio',
                        'choices'        => array(
                            'info'   => __( 'Informačná lišta', 'idsk-template' ),
                            'warning'  => __( 'Lišta s varovaním', 'idsk-template' )
                        )
                    )
                );
                
                // Show breadcrumbs on subpages
                $wp_customize->add_setting(
                    'idsktmp_show_breadcrumbs',
                    array(
                        'capability'        => 'edit_theme_options',
                        'default'           => false,
                        'sanitize_callback' => array( __CLASS__, 'idsktmp_sanitize_checkbox' )
                    )
                );
                $wp_customize->add_control(
                    'idsktmp_show_breadcrumbs',
                    array(
                        'type'     => 'checkbox',
                        'section'  => 'idsktmp_main_settings',
                        'label'    => __( 'Zobraziť breadcrumbs na podstránkach', 'idsk-template' ),
                    )
                );
                
                // Show version info 
                $wp_customize->add_setting(
                    'idsktmp_show_version_info',
                    array(
                        'sanitize_callback' => array( __CLASS__, 'idsktmp_sanitize_text' )
                    )
                );
                $wp_customize->add_control(
                    'idsktmp_show_version_info',
                    array(
                        'label'      => __( 'Verzia webových stránok', 'idsk-template' ),
                        'description' => __( 'Ak verzia nieje zadaná, blok sa nezobrazí.', 'idsk-template' ),
                        'section'    => 'idsktmp_main_settings',
                        'settings'   => 'idsktmp_show_version_info',
                        'type'       => 'text'
                    )
                );

                $wp_customize->add_setting(
                    'idsktmp_show_version_info_text',
                    array(
                        'sanitize_callback' => array( __CLASS__, 'idsktmp_sanitize_text' )
                    )
                );
                $wp_customize->add_control(
                    'idsktmp_show_version_info_text',
                    array(
                        'label'      => __( 'Textová informácia k verzii webových stránok', 'idsk-template' ),
                        'section'    => 'idsktmp_main_settings',
                        'settings'   => 'idsktmp_show_version_info_text',
                        'type'       => 'text'
                    )
                );

                $wp_customize->add_setting(
                    'idsktmp_show_version_info_date',
                    array(
                        'sanitize_callback' => array( __CLASS__, 'idsktmp_sanitize_text' )
                    )
                );
                $wp_customize->add_control(
                    'idsktmp_show_version_info_date',
                    array(
                        'label'      => __( 'Dátum vydania verzie webových stránok', 'idsk-template' ),
                        'section'    => 'idsktmp_main_settings',
                        'settings'   => 'idsktmp_show_version_info_date',
                        'type'       => 'text'
                    )
                );

            /**
             * Alert panel
             */
            $wp_customize->add_section(
                'idsktmp_alert_panel',
                array(
                    'title'       => __( 'Výstražný panel', 'idsk-template' ),
                    'description' => __( 'Zobrazuje panel v hlavičke stránky. Pre zobrazenie panela musí byť vyplnený jeho nadpis.', 'idsk-template' ),
                    'priority'    => 15,
                )
            );
                
                // Confirmation panel
                $wp_customize->add_setting(
                    'idsktmp_alert_panel_success',
                    array(
                        'capability'        => 'edit_theme_options',
                        'default'           => false,
                        'sanitize_callback' => array( __CLASS__, 'idsktmp_sanitize_checkbox' )
                    )
                );
                $wp_customize->add_control(
                    'idsktmp_alert_panel_success',
                    array(
                        'type'     => 'checkbox',
                        'section'  => 'idsktmp_alert_panel',
                        'label'    => __( 'Zobraziť panel potvrdenia', 'idsk-template' )
                    )
                );

                // Panel heading
                $wp_customize->add_setting(
                    'idsktmp_alert_panel_heading',
                    array(
                        'sanitize_callback' => array( __CLASS__, 'idsktmp_sanitize_text' )
                    )
                );
                $wp_customize->add_control(
                    'idsktmp_alert_panel_heading',
                    array(
                        'label'      => __( 'Nadpis panela', 'idsk-template' ),
                        'section'    => 'idsktmp_alert_panel',
                        'type'       => 'text'
                    )
                );

                // Panel text
                $wp_customize->add_setting(
                    'idsktmp_alert_panel_text',
                    array(
                        'sanitize_callback' => array( __CLASS__, 'idsktmp_sanitize_text' )
                    )
                );
                $wp_customize->add_control(
                    'idsktmp_alert_panel_text',
                    array(
                        'label'      => __( 'Textový obsah panela', 'idsk-template' ),
                        'section'    => 'idsktmp_alert_panel',
                        'type'       => 'textarea'
                    )
                );

        }

        /**
         * Check if footer_extended_feedback_form is allowed
         * 
         * @return bool
         */
        public static function idsktmp_is_footer_extended_feedback_form() {
            return true === get_theme_mod( 'idsktmp_footer_exteded_feedback_form', true );
        }

        /**
         * Sanitize boolean for checkbox.
         *
         * @param bool $checked Whether or not a box is checked.
         * @return bool
         */
        public static function idsktmp_sanitize_checkbox( $checked ) {
            return ( ( isset( $checked ) && true === $checked ) ? true : false );
        }
        
        /**
         * Sanitize images for uploads.
         *
         * @return image
         */
        public static function idsktmp_sanitize_images( $file, $setting ) {
          
            //allowed file types
            $mimes = array(
                'jpg|jpeg|jpe' => 'image/jpeg',
                'gif'          => 'image/gif',
                'png'          => 'image/png',
                'bmp'          => 'image/bmp',
                'svg'          => 'image/svg+xml'
            );
              
            //check file type from file name
            $file_ext = wp_check_filetype( $file, $mimes );
              
            //if file has a valid mime type return it, otherwise return default
            return ( $file_ext['ext'] ? $file : $setting->default );
        }

        /**
         * Sanitize radio controls
         * 
         */
        public static function idsktmp_sanitize_radio( $input, $setting ) {
            // Ensure input is a slug.
            $input = sanitize_key( $input );
            // Get list of choices from the control associated with the setting.
            $choices = $setting->manager->get_control( $setting->id )->choices;
            // If the input is a valid key, return it; otherwise, return the default.
            return ( array_key_exists( $input, $choices ) ? $input : $setting->default );
        }

        /**
         * Sanitize text
         */
        public static function idsktmp_sanitize_text( $string ) {
            $allowedtags = array(
                'strong' => array(),
                'a' => array(
			        'href' => array(),
			        'title' => array(),
			        'class' => array(),
                    'target' => array(),
                    'aria-label' => array(),
                    'id' => array()
			    ),
            );

            return wp_kses( $string , $allowedtags );
        }

    }
    
    add_action( 'customize_register', array( 'Idsktmp_Customize', 'idsktmp_register' ) );

}

