<?php
/**
 * ID-SK theme - comments
 * 
 * @link https://slovenskoit.sk
 *
 * @package WordPress
 * @subpackage ID-SK
 * @since ID-SK 1.0
 */

/*
 * If the current post is protected by a password and
 * the visitor has not yet entered the password,
 * return early without loading the comments.
 */
if ( post_password_required() ) {
	return;
}

$idsk_comment_count = get_comments_number();
?>

<div id="comments" class="comments-area default-max-width <?php echo esc_attr(get_option( 'show_avatars' )) ? 'show-avatars' : ''; ?>">

	<?php
	if ( have_comments() ) :
		;
		?>
		<h2 class="govuk-heading-m">
			<?php if ( '1' === $idsk_comment_count ) : ?>
				<?php esc_html_e( '1 komentár', 'idsk-template' ); ?>
			<?php else : ?>
				<?php
				printf(
					/* translators: %s: the number of comments. */
					esc_html( _nx( '%s komentár', '%s komentárov', $idsk_comment_count, 'Titulok komentára', 'idsk-template' ) ),
					esc_html( number_format_i18n( $idsk_comment_count ) )
				);
				?>
			<?php endif; ?>
		</h2>

		<ol class="govuk-list">
			<?php
			wp_list_comments(
				array(
					'callback' => 'idsktmp_comment'
				)
			);
			?>
		</ol>

		<?php
			$comment_pages = paginate_comments_links(array(
						'echo'      => false, 
						'type'      => 'array', 
						'prev_text' => sprintf(
							'%s %s',
							is_rtl() ? esc_html__( '>', 'idsk-template' ) : esc_html__( '<', 'idsk-template' ),
							esc_html__( 'Staršie komentáre', 'idsk-template' )
						),
						'next_text' => sprintf(
							'%s %s',
							esc_html__( 'Novšie komentáre', 'idsk-template' ),
							is_rtl() ? esc_html__( '<', 'idsk-template' ) : esc_html__( '>', 'idsk-template' )
						),
				));

			if( is_array( $comment_pages ) ) {
				$output = '';

				foreach ($comment_pages as $comment_page) {

					$customPage = str_replace('<a class="', '<a class="govuk-button govuk-button--secondary ', $comment_page);
					$customPage = str_replace('<span aria-current="page" class="', '<span aria-current="page" class="govuk-button ', $customPage);

					$output .= $customPage;
				}

				echo wp_kses($output, array('a' => array( 'href' => array(), 'class' => array(), 'title' => array() ), 'span' => array( 'aria-current' => array(), 'class' => array() )));
			}
		?>

		<?php if ( ! comments_open() ) : ?>
			<h2 class="govuk-heading-m"><?php esc_html_e( 'Komentáre sú uzavreté.', 'idsk-template' ); ?></h2>
		<?php endif; ?>
	<?php endif; ?>

	<?php
	comment_form(
		array(
			'logged_in_as'       => null,
			'title_reply'        => esc_html__( 'Zanechajte komentár', 'idsk-template' ),
			'submit_button'      => '<button name="%1$s" type="submit" id="%2$s" class="%3$s idsk-button">%4$s</button>',
		)
	);
	?>

</div><!-- #comments -->
